Pennies
=======

|Build Status| |Coverage|

Pythonic Finance Sandbox

LICENSE
-------

New BSD. See `License File <https://github.com/caseyclements/pennies/blob/master/LICENSE>`__.

.. |Build Status| image:: https://travis-ci.org/caseyclements/pennies.svg?branch=master
   :target: https://travis-ci.org/caseyclements/pennies
.. |Coverage| image:: https://coveralls.io/repos/github/caseyclements/pennies/badge.svg?branch=master
   :target: https://coveralls.io/github/caseyclements/pennies
